import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from django.db.models import Sum
from employee.models import CurEmpDivision
from contract.models import Contract, EmpPosition
from perform.models import EvalYear, Eval, Evaluator, EvalFinalScore, EvalType, EvalPlanning
from perform.forms import *
from settings_app.utils import getnewid
from settings_app.user_utils import c_unit, c_staff

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformAdd(request):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	year = EvalYear.objects.filter(is_active=True).first()
	de = EmpPosition.objects.filter(position_id=1).first()
	deputy = EmpPosition.objects.filter(position_id=2).first()
	if request.method == 'POST':
		newid, new_hashid = getnewid(Eval)
		form = EvalForm(c_emp, unit, request.POST)
		if form.is_valid():
			emp = form.cleaned_data.get('employee')
			contract = Contract.objects.filter(employee=emp).first()
			empdiv = CurEmpDivision.objects.get(employee=emp)
			check = Eval.objects.filter(employee=emp, year=year).first()
			if check:
				messages.error(request, f'Dadus iha ona.')
				return redirect('c-eval-list')
			instance = form.save(commit=False)
			instance.id = newid
			instance.year = year
			instance.category = contract.category
			instance.position = contract.position
			if contract.category_id == 5: instance.is_dep = True
			if empdiv.department: instance.department = empdiv.department
			elif empdiv.unit: instance.unit = empdiv.unit
			instance.datetime = datetime.datetime.now()
			instance.user = request.user
			instance.hashed = new_hashid
			instance.save()
			obj = Evaluator(id=newid, eval_id=newid, employee=c_emp, unit=unit,\
				position=c_emp.curempposition.position)
			obj.save()
			messages.success(request, f'Aumeta sucessu.')
			return redirect('c-eval-detail', hashid=new_hashid)
	else: form = EvalForm(c_emp, unit)
	context = {
		'group': group, 'form': form, 'page': 'unit',
		'title': 'Prenche Avaliasaun', 'legend': 'Prenche Avaliasaun'
	}
	return render(request, 'perform2/form_eval.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformUpdate(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = get_object_or_404(Eval, hashed=hashid)
	if request.method == 'POST':
		form = EvalForm2(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.save()
			messages.success(request, f'Altera sucessu.')
			return redirect('c-eval-detail', hashid=hashid)
	else: form = EvalForm2(instance=objects)
	context = {
		'group': group, 'form': form, 'page': 'unit',
		'title': 'Prenche Avaliasaun', 'legend': 'Prenche Avaliasaun'
	}
	return render(request, 'perform2/form_eval.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformRemove(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = get_object_or_404(Eval, hashed=hashid)
	objects.delete()
	messages.success(request, f'Hapaga sucessu.')
	return redirect('c-eval-list')



@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformUnlock(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = get_object_or_404(Eval, hashed=hashid)
	objects.is_lock = False
	objects.save()
	messages.success(request, f'Loke.')
	return redirect('c-eval-detail', hashid=hashid)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformFinish(request, hashid):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = get_object_or_404(Eval, hashed=hashid)
	objects.is_finish = True
	objects.save()
	messages.success(request, f'Termina.')
	return redirect('c-eval-detail', hashid=hashid)
#
@login_required
def cPerformRefresh(request, hashid, hashid2):
	eval = get_object_or_404(Eval, hashed=hashid)
	plan = get_object_or_404(EvalPlanning, hashed=hashid2)
	sum_a = EvalDetA.objects.filter(eval=eval).aggregate(Sum('choice__score')).get('choice__score__sum', 0.00)
	sum_b = EvalDetB.objects.filter(eval=eval).aggregate(Sum('choice__score')).get('choice__score__sum', 0.00)
	total_a, total_b, total = 0,0,0
	if sum_a: total_a = sum_a
	if sum_b: total_b = sum_b
	total = float(total_a) + float(total_b)
	eval.score_a = total_a
	eval.score_b = total_b
	eval.total = total
	eval.save()
	final = EvalFinalScore.objects.filter(eval=eval).last()
	print(final)
	total = int(total)
	print(total)
	if total >= 80: 
		final.a = total
		final.b, final.c, final.d, final.e = None,None,None,None
	elif total >= 60: 
		final.b = total
		final.a, final.c, final.d, final.e = None,None,None,None
	elif total >= 40: 
		final.c = total
		final.a, final.b, final.d, final.e = None,None,None,None
	elif total >= 20: 
		final.d = total
		final.a, final.b, final.c, final.e, = None,None,None,None
	elif total >= 0: 
		final.e = total
		final.a, final.b, final.c, final.d = None,None,None,None
	final.save()
	messages.success(request, f'Altera sucessu.')
	return redirect('eval-evaluator-detail', hashid=hashid, hashid2=plan.hashed)
###
@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformDate1Update(request, pk):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	evaldate = get_object_or_404(EvalDate, pk=pk)
	eval = evaldate.eval
	if request.method == 'POST':
		form = EvalDateForm1(request.POST, instance=evaldate)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.save()
			messages.success(request, f'Aumeta sucessu.')
			return redirect('c-eval-detail', hashid=eval.hashed)
	else: form = EvalDateForm1(instance=evaldate)
	context = {
		'group': group, 'form': form, 'page': 'unit',
		'title': 'Hadia Data', 'legend': 'Hadia Data'
	}
	return render(request, 'perform2/form_eval.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def cPerformDate2Update(request, pk):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	evaldate = get_object_or_404(EvalDate, pk=pk)
	eval = evaldate.eval
	if request.method == 'POST':
		form = EvalDateForm2(request.POST, instance=evaldate)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.save()
			messages.success(request, f'Aumeta sucessu.')
			return redirect('c-eval-detail', hashid=eval.hashed)
	else: form = EvalDateForm2(instance=evaldate)
	context = {
		'group': group, 'form': form, 'page': 'unit',
		'title': 'Hadia Data', 'legend': 'Hadia Data'
	}
	return render(request, 'perform2/form_eval.html', context)


### NEW
@login_required
def PerfomConfAddEval(request, hashid, year):
	group = request.user.groups.all()[0].name
	employee = get_object_or_404(Employee, hashed=hashid)
	pyear = get_object_or_404(EvalYear, year=year)
	ptype = get_object_or_404(EvalType, pk=4)
	contract = Contract.objects.filter(employee=employee, is_active=True).last()
	empdiv = CurEmpDivision.objects.filter(employee=employee).last()
	newid, new_hashid = getnewid(Eval)
	obj = Eval(
		id = newid,
		hashed= new_hashid,
		year = pyear,
		type = ptype,
		employee = employee,
		is_lock = True,
		category = contract.category,
		position = contract.position,
		department = empdiv.department,
		unit = empdiv.unit
	)
	obj.save()
	plan = EvalPlanning.objects.filter(employee=employee, year__year=year).last()
	objects = EvalPlanningA.objects.filter(eval__employee=employee, eval__year__year=year).all()
	objects2 = EvalPlanningB.objects.filter(eval__employee=employee, eval__year__year=year).all()
	
	
	for i in objects:
		newid2, new_hashid2 = getnewid(EvalDetA)
		obj2 = EvalDetA(id=newid2, eval=obj, parameter=i,\
			user=request.user, hashed=new_hashid2)
		obj2.save()
	for j in objects2:
		newid3, new_hashid3 = getnewid(EvalDetB)
		obj3 = EvalDetB(id=newid3, eval=obj, parameter=j,\
			user=request.user, hashed=new_hashid3)
		obj3.save()
	messages.success(request, 'Susesu Kria Self Evaluation Sheet')
	if group == 'hr':
		return redirect('eval-detail-eval', hashid=obj.hashed, hashid2=plan.hashed)
	else:
		return redirect('staff-eval-detail', hashid=obj.hashed, hashid2=plan.hashed)

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def PerfomEvalDetail(request, hashid, hashid2):
    objects = get_object_or_404(Eval,hashed=hashid)
    user = c_staff(request.user)
    plan = get_object_or_404(EvalPlanning,hashed=hashid2)
    check_emp = True if user == objects.employee else False
    individual = EvalDetA.objects.filter(eval=objects)
    behavior = EvalDetB.objects.filter(eval=objects)
    finalscore = EvalFinalScore.objects.filter(eval=objects).last()
    context = {
        'title': 'Detail Evaluation', 'legend': 'Evaluation Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior, \
		'plan':plan, 'finalscore':finalscore
    }
    return render(request,'perform2/eval_detail.html', context)



##EVALUATOR

@login_required
def PerfomEvalEvaluatorAdd(request, hashid, hashid2):
    emp, unit = c_unit(request.user)
    eval = get_object_or_404(Eval,hashed=hashid)
    contract = Contract.objects.filter(employee=emp, is_active=True).last()
    empdiv = CurEmpDivision.objects.filter(employee=emp).last()
    plan = get_object_or_404(EvalPlanning,hashed=hashid2)
    eval.employeeeval = emp
    eval.positioneval = contract.position
    eval.uniteval = empdiv.unit
    eval.save()
    messages.success(request, f'Chave Sucessu')
    return redirect('eval-evaluator-detail', hashid=eval.hashed,  hashid2=plan.hashed )

@login_required
def PerfomEvalEvaluatorDetail(request, hashid, hashid2):
    objects = get_object_or_404(Eval,hashed=hashid)
    user = c_staff(request.user)
    plan = get_object_or_404(EvalPlanning,hashed=hashid2)
    check_emp = True if user == objects.employee else False
    individual = EvalDetA.objects.filter(eval=objects)
    behavior = EvalDetB.objects.filter(eval=objects)
    finalscore = EvalFinalScore.objects.filter(eval=objects).last()
    context = {
        'title': 'Detail Evaluation', 'legend': 'Evaluation Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior, \
		'plan':plan, 'finalscore':finalscore
    }
    return render(request,'perform2/evaluator_eval_detail.html', context)


@login_required
def cPerformLock(request, hashid, hashid2):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = get_object_or_404(Eval, hashed=hashid)
	plan = get_object_or_404(EvalPlanning, hashed=hashid2)
	objects.is_finish = True
	objects.save()
	messages.success(request, f'Susesu Chave')
	return redirect('eval-evaluator-detail', hashid=hashid, hashid2=plan.hashed)


# Generated by Django 3.2 on 2023-02-16 09:58

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('perform', '0002_evalchoiceplanning_evalplanning'),
    ]

    operations = [
        migrations.CreateModel(
            name='EvalPlanningB',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('progress', models.TextField(blank=True, null=True)),
                ('dificulties', models.TextField(blank=True, null=True)),
                ('need_improv', models.TextField(blank=True, null=True)),
                ('datetime', models.DateTimeField(blank=True, null=True)),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalplanningb', to='perform.evalplanning')),
                ('parameter', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalplanningb', to='perform.parameterb')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='EvalPlanningA',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('goals', models.TextField(blank=True, null=True, verbose_name='Goas/Activities')),
                ('measuring', models.TextField(blank=True, null=True, verbose_name='Measuring Indicator')),
                ('criteria', models.TextField(blank=True, null=True, verbose_name='Criteria for Overcoming')),
                ('score', models.DecimalField(blank=True, decimal_places=2, max_digits=11, null=True)),
                ('progress', models.TextField(blank=True, null=True, verbose_name='Progress')),
                ('dificulties', models.TextField(blank=True, null=True, verbose_name='Dificulties')),
                ('need_improv', models.TextField(blank=True, null=True, verbose_name='Need Improvement')),
                ('hashed', models.CharField(blank=True, max_length=32, null=True)),
                ('eval', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalplanninga', to='perform.evalplanning')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]



# Generated by Django 3.2 on 2023-02-18 08:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0016_auto_20230218_1718'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalself',
            old_name='eval_beh_date',
            new_name='beh_date',
        ),
        migrations.RenameField(
            model_name='evalself',
            old_name='eval_ind_date',
            new_name='ind_date',
        ),
    ]



# Generated by Django 3.2 on 2023-02-16 14:05

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('perform', '0005_evalplanninga_enter_date'),
    ]

    operations = [
        migrations.AddField(
            model_name='evalplanninga',
            name='usereval',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='evalplanningauser', to=settings.AUTH_USER_MODEL),
        ),
    ]



import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from django.db.models import Sum
from employee.models import CurEmpDivision, Employee
from contract.models import Category, Contract, EmpPosition
from perform.models import ParameterA, ParameterB, Eval, EvalDetA, EvalDetB, EvalYear, \
EvalPlanning, EvalPlanningA, EvalPlanningB, EvalPreAssessment, EvalPreAssessmentA, EvalSelf, \
EvalSelfDetA, EvalSelfDetB
from perform.forms import *
from settings_app.utils import getnewid

@login_required
def PerformConfDash(request):
	group = request.user.groups.all()[0].name
	paramas = ParameterA.objects.filter().all()
	parambs = ParameterB.objects.filter().all()
	years = EvalYear.objects.filter().all().order_by('year')
	employee = Employee.objects.filter(status_id=1).exclude(curempdivision__de__pk=1)
	ayear = EvalYear.objects.filter(is_active=True).last()
	objects = []
	for emp in employee:
		evalplan = EvalPlanning.objects.filter(employee=emp, year=ayear).last()
		evalpreass = EvalPreAssessment.objects.filter(employee=emp, year=ayear).last()
		check_plan = EvalPlanningA.objects.filter(eval=evalplan).exists()
		evalself = EvalSelf.objects.filter(employee=emp, year=ayear).last()
		eval = Eval.objects.filter(employee=emp, year=ayear).last()
		objects.append([emp,evalplan, evalpreass, check_plan, evalself, eval])


	context = {
		'group': group, 'years': years, 'paramas': paramas, 'parambs': parambs,
		'title': 'Konfigurasaun Avaliasaun', 'legend': 'Konfigurasaun Avaliasaun', \
		'objects': objects, 'ayear':ayear.year
	}
	return render(request, 'perform2_conf/conf_dash.html', context)


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def PerformYearActive(request, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(EvalYear, pk=pk)
	objects2 = EvalYear.objects.filter().exclude(pk=pk).all()
	objects.is_active = True
	objects.save()
	for i in objects2:
		i.is_active = False
		i.save()
	messages.success(request, f'Ativa sucessu.')
	return redirect('eval-conf-dash')
#
@login_required
def ParameterAAdd(request):
	group = request.user.groups.all()[0].name
	if request.method == 'POST':
		newid, _ = getnewid(ParameterA)
		form = ParameterAForm(request.POST)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.id = newid
			instance.save()
			messages.success(request, f'Altera sucessu.')
			if group == "unit": return redirect('eval-conf-dash')
	else: form = ParameterAForm()
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Aumenta Parameter', 'legend': 'Aumenta Parameter'
	}
	return render(request, 'perform2_conf/form.html', context)

@login_required
def ParameterAUpdate(request, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(ParameterA, pk=pk)
	if request.method == 'POST':
		form = ParameterAForm(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			messages.success(request, f'Altera sucessu.')
			if group == "unit": return redirect('eval-conf-dash')
	else: form = ParameterAForm(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Hadia Parameter', 'legend': 'Hadia Parameter'
	}
	return render(request, 'perform2_conf/form.html', context)
#
@login_required
def ParameterBAdd(request):
	group = request.user.groups.all()[0].name
	if request.method == 'POST':
		newid, _ = getnewid(ParameterB)
		form = ParameterBForm(request.POST)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.id = newid
			instance.save()
			messages.success(request, f'Altera sucessu.')
			if group == "unit": return redirect('eval-conf-dash')
	else: form = ParameterBForm()
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Aumenta Parameter', 'legend': 'Aumenta Parameter'
	}
	return render(request, 'perform2_conf/form.html', context)

@login_required
def ParameterBUpdate(request, pk):
	group = request.user.groups.all()[0].name
	objects = get_object_or_404(ParameterB, pk=pk)
	if request.method == 'POST':
		form = ParameterBForm(request.POST, instance=objects)
		if form.is_valid():
			instance = form.save(commit=False)
			instance.datetime = datetime.datetime.now()
			instance.save()
			messages.success(request, f'Altera sucessu.')
			return redirect('eval-conf-behavior-list')
	else: form = ParameterBForm(instance=objects)
	context = {
		'group': group, 'eval': eval, 'form': form,
		'title': 'Hadia Parameter', 'legend': 'Hadia Parameter'
	}
	return render(request, 'perform2_conf/form.html', context)


##BEHAVIORS

@login_required
@allowed_users(allowed_roles=['admin','hr'])
def PerformConfBehaviorList(request):
	group = request.user.groups.all()[0].name
	objects = ParameterB.objects.filter().all()


	context = {
		'group': group,
		'title': 'Lista Behavior', 'legend': 'Lista Behavior', \
		'objects': objects, 
	}
	return render(request, 'perform2/behavior_list.html', context)

@login_required
def PerformConfBehaviorAdd(request, hashid):
	objects = get_object_or_404(EvalPlanning, hashed=hashid)
	group = request.user.groups.all()[0].name
	parameter = ParameterB.objects.filter().all()
	for par in parameter:
		newid, new_hashid = getnewid(EvalPlanningB)
		obj = EvalPlanningB(
			id=newid,
			eval = objects,
			hashed = new_hashid,
			parameter = par,
			user = request.user
		)
		obj.save()
	messages.success(request, 'Susesu Aumenta')
	if group == 'hr':
		return redirect('eval-conf-plan-detail', hashid)
	else:
		return redirect('staff-perform-plan-detail',hashid)


import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from django.db.models import Sum
from employee.models import CurEmpDivision, Employee
from contract.models import Category, Contract, EmpPosition
from perform.models import ParameterA, ParameterB, Eval, EvalDetA, EvalDetB, EvalYear, \
EvalPlanning, EvalPlanningA, EvalPlanningB, EvalType
from perform.forms import *
from settings_app.utils import getnewid



@login_required
@allowed_users(allowed_roles=['admin','hr'])
def PerfomConfAddPlan(request, hashid, year):
    employee = get_object_or_404(Employee, hashed=hashid)
    pyear = get_object_or_404(EvalYear, year=year)
    ptype = get_object_or_404(EvalType, pk=1)
    contract = Contract.objects.filter(employee=employee, is_active=True).last()
    if contract:
        empdiv = CurEmpDivision.objects.filter(employee=employee).last()
        newid, new_hashid = getnewid(EvalPlanning)
        obj = EvalPlanning(
            id = newid,
            hashed= new_hashid,
            year = pyear,
            type = ptype,
            employee = employee,
            category = contract.category,
            position = contract.position,
            department = empdiv.department,
            unit = empdiv.unit
        )
        obj.save()
        messages.success(request, 'Susesu Kria Planning and Monitoring Sheet')
        return redirect('eval-conf-dash')
    else:
        messages.error(request, 'Funsionario Seidauk Iha Kontrato')
        return redirect('eval-conf-dash')


@login_required
@allowed_users(allowed_roles=['admin','hr'])
def PerfomConfAddPlanAll(request, year):
    pyear = get_object_or_404(EvalYear, year=year)
    ptype = get_object_or_404(EvalType, pk=1)
    employees = Employee.objects.filter(status_id=1).exclude(curempdivision__de__pk=1)
    for emp in employees:
        check_emp_plan = EvalPlanning.objects.filter(employee=emp, year=pyear).last()
        if not check_emp_plan:
            contract = Contract.objects.filter(employee=emp, is_active=True).last()
            if contract:
                empdiv = CurEmpDivision.objects.filter(employee=emp).last()
                newid, new_hashid = getnewid(EvalPlanning)
                obj = EvalPlanning(
                    id = newid,
                    hashed= new_hashid,
                    year = pyear,
                    type = ptype,
                    employee = emp,
                    category = contract.category,
                    position = contract.position,
                    department = empdiv.department,
                    unit = empdiv.unit
                )
                obj.save()
                messages.success(request, 'Susesu Kria Planning and Monitoring Sheet')
                return redirect('eval-conf-dash')
            else:
                messages.error(request, f'Funsionario {emp} Seidauk Iha Kontrato')
                return redirect('eval-conf-dash')

                




from django.shortcuts import render, get_object_or_404
from django.contrib.auth.decorators import login_required
from employee.models import Employee
from perform.utils import f_finalscore
from settings_app.decorators import allowed_users
from django.db.models import Sum, Count, Q
from contract.models import Category, Contract, EmpPosition
from perform.models import *
from settings_app.user_utils import c_staff, c_dep, c_unit

@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformList(request):
	group = request.user.groups.all()[0].name
	if group == "staff": c_emp = c_staff(request.user)
	elif group == "dep": c_emp, _ = c_dep(request.user)
	elif group == "unit": c_emp, _ = c_unit(request.user)
	elif group == "hr": c_emp, _ = c_unit(request.user)
	objects = EvalSelf.objects.filter(employee=c_emp).all().order_by('-start_date')
	context = {
		'group': group, 'c_emp': c_emp, 'objects': objects, 'page': 'list',
		'title': f'Lista Avaliasaun', 'legend': f'Lista Avaliasaun'
	}
	return render(request, 'perform2_self/eval_list.html', context)

@login_required
@allowed_users(allowed_roles=['staff','dep','unit','hr'])
def selfPerformDetail(request, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(EvalSelf, hashed=hashid)
	obj_as = EvalSelfDetA.objects.filter(eval=eval).all()
	obj_bs = EvalSelfDetB.objects.filter(eval=eval).all()
	context = {
		'group': group, 'eval': eval, 'obj_as': obj_as, 'obj_bs': obj_bs,
		'title': f'Detalha Avaliasaun', 'legend': f'Detalha Avaliasaun'
	}
	return render(request, 'perform2_self/eval_detail.html', context)
###
@login_required
@allowed_users(allowed_roles=['hr','de','deputy'])
def selfPerformAllList(request):
	group = request.user.groups.all()[0].name
	objects = EvalSelf.objects.filter().all().order_by('-start_date')
	years = EvalSelf.objects.filter().distinct().values('year__year').all()
	context = {
		'group': group, 'objects': objects, 'years': years,
		'title': f'Lista Avaliasaun Pessoal', 'legend': f'Lista Avaliasaun Pessoal'
	}
	return render(request, 'perform2_self/all_eval_list.html', context)

@login_required
@allowed_users(allowed_roles=['hr','de','deputy'])
def selfPerformYearList(request, year):
	group = request.user.groups.all()[0].name
	objects, years = [],[]
	objects = EvalSelf.objects.filter(year__year=year).all().order_by('-start_date')
	years = EvalSelf.objects.filter().distinct().values('year__year').all()
	context = {
		'group': group, 'objects': objects, 'years': years,
		'title': f'Lista Avaliasaun Pessoal', 'legend': f'Lista Avaliasaun Pessoal'
	}
	return render(request, 'perform2_self/all_eval_list.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def selfPerformUnitList(request):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects = EvalSelf.objects.filter((Q(employee__curempdivision__department__unit=unit)\
		|Q(employee__curempdivision__unit=unit))).all().order_by('-start_date')
	years = EvalSelf.objects.filter((Q(employee__curempdivision__department__unit=unit)\
		|Q(employee__curempdivision__unit=unit))).distinct().values('year__year').all()
	context = {
		'group': group, 'unit': unit, 'objects': objects, 'years': years, 'page': 'list',
		'title': f'Lista Avaliasaun Pessoal', 'legend': f'Lista Avaliasaun Pessoal'
	}
	return render(request, 'perform2_self/eval_unit_list.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr'])
def selfPerformUnitYearList(request, year):
	group = request.user.groups.all()[0].name
	c_emp, unit = c_unit(request.user)
	objects, years = [],[]
	objects = EvalSelf.objects.filter((Q(employee__curempdivision__department__unit=unit)\
		|Q(employee__curempdivision__unit=unit)), year__year=year).all().order_by('-start_date')
	years = EvalSelf.objects.filter((Q(employee__curempdivision__department__unit=unit)\
		|Q(employee__curempdivision__unit=unit))).distinct().values('year__year').all()
	context = {
		'group': group, 'objects': objects, 'years': years,
		'title': f'Lista Avaliasaun Pessoal', 'legend': f'Lista Avaliasaun Pessoal'
	}
	return render(request, 'perform2_self/eval_unit_list.html', context)

@login_required
@allowed_users(allowed_roles=['unit','hr','de','deputy'])
def selfPerformAllDetail(request, hashid):
	group = request.user.groups.all()[0].name
	eval = get_object_or_404(EvalSelf, hashed=hashid)
	obj_as = EvalSelfDetA.objects.filter(eval=eval).all()
	obj_bs = EvalSelfDetB.objects.filter(eval=eval).all()
	context = {
		'group': group, 'eval': eval, 'obj_as': obj_as, 'obj_bs': obj_bs,
		'title': f'Detalha Avaliasaun', 'legend': f'Detalha Avaliasaun'
	}
	return render(request, 'perform2_self/all_eval_detail.html', context)


#### NEW

@login_required
def PerfomConfSelfDetail(request, hashid):
    objects = get_object_or_404(EvalSelf,hashed=hashid)
    user = c_staff(request.user)
    check_emp = True if user == objects.employee else False
    individual = EvalSelfDetA.objects.filter(eval=objects)
    behavior = EvalSelfDetB.objects.filter(eval=objects)
    context = {
        'title': 'Detail Self Evaluation', 'legend': 'Self Evaluation Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior
    }
    return render(request,'perform2/self_detail.html', context)


@login_required
def PerfomEvaluatorSelfDetail(request, hashid):
    objects = get_object_or_404(EvalSelf,hashed=hashid)
    user = c_staff(request.user)
    check_emp = True if user == objects.employee else False
    individual = EvalSelfDetA.objects.filter(eval=objects)
    behavior = EvalSelfDetB.objects.filter(eval=objects)
    context = {
        'title': 'Detail Self Evaluation', 'legend': 'Self Evaluation Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior
    }
    return render(request,'perform2/evaluator_self_detail.html', context)


from django.db import models
from django.contrib.auth.models import User
from contract.models import Category
from custom.models import Department, Position, Unit
from employee.models import Employee

class EvalMonth(models.Model):
	month = models.CharField(max_length=100, null=True, blank=True)
	def __str__(self):
		template = '{0.month}'
		return template.format(self)
	
class EvalYear(models.Model):
	year = models.IntegerField(null=True, blank=True)
	is_active = models.BooleanField(default=False, null=True)
	def __str__(self):
		template = '{0.year} : {0.is_active}'
		return template.format(self)

class EvalType(models.Model):
	name = models.CharField(max_length=100, null=True, blank=True)

	def __str__(self):
		template = '{0.name}'
		return template.format(self)

class EvalChoice(models.Model):
	name = models.CharField(max_length=100, null=True, blank=True)
	score = models.IntegerField(null=True, blank=True)
	def __str__(self):
		template = '{0.name}: {0.score}'
		return template.format(self)
	
class EvalChoicePlanning(models.Model):
	name = models.CharField(max_length=100, null=True, blank=True)
	score = models.IntegerField(null=True, blank=True)
	def __str__(self):
		template = '{0.name}: {0.score}'
		return template.format(self)
#
class ParameterA(models.Model):
	name = models.CharField(max_length=100, null=True, blank=True)
	measure = models.TextField(null=True, blank=True)
	criteria = models.TextField(null=True, blank=True)
	def __str__(self):
		template = '{0.name}'
		return template.format(self)

class ParameterB(models.Model):
	area = models.CharField(max_length=100, null=True, blank=True)
	indicator = models.TextField(null=True, blank=True)
	def __str__(self):
		template = '{0.area}'
		return template.format(self)

# EVAL PLANNING
class EvalPlanning(models.Model):
	month = models.CharField(max_length=100, null=True, blank=True)
	year = models.ForeignKey(EvalYear, on_delete=models.CASCADE, null=True, blank=True, related_name="planningeval")
	type = models.ForeignKey(EvalType, on_delete=models.CASCADE, null=True, blank=True, related_name="planningeval")
	employeeeval = models.ForeignKey(Employee, on_delete=models.CASCADE, null=True, blank=True, related_name="planningempeval")
	positioneval = models.ForeignKey(Position, on_delete=models.CASCADE, null=True, blank=True, related_name="planningempeval")
	uniteval = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name='planningempeval')
	employee = models.ForeignKey(Employee, on_delete=models.CASCADE, null=True, blank=True, related_name="planningemp")
	category = models.ForeignKey(Category, on_delete=models.CASCADE, null=True, blank=True, related_name='planningemp')
	position = models.ForeignKey(Position, on_delete=models.CASCADE, null=True, blank=True, related_name='planningemp')
	department = models.ForeignKey(Department, on_delete=models.CASCADE, null=True, blank=True, related_name='planningeval')
	unit = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name='planningemp')
	start_date = models.DateField(null=True, blank=True)
	end_date = models.DateField(null=True, blank=True)
	eval_date_obj = models.DateField(null=True, blank=True)
	eval_date_ind = models.DateField(null=True, blank=True)
	obj_date = models.DateField(null=True, blank=True)
	ind_date = models.DateField(null=True, blank=True)
	objective = models.TextField(null=True, blank=True, verbose_name="Objectives")
	is_lock = models.BooleanField(default=False, null=True)
	is_finish = models.BooleanField(default=False, null=True)
	datetime = models.DateTimeField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.employee} - {0.year.year}'
		return template.format(self)

class EvalPlanningA(models.Model):
	eval = models.ForeignKey(EvalPlanning, on_delete=models.CASCADE, null=True, blank=True, related_name="evalplanninga")
	goals = models.TextField(null=True, blank=True, verbose_name="Goas/Activities")
	measuring = models.TextField(null=True, blank=True, verbose_name="Measuring Indicator")
	criteria = models.TextField(null=True, blank=True, verbose_name="Criteria for Overcoming")
	score = models.DecimalField(max_digits=11, decimal_places=2, null=True, blank=True)
	progress = models.TextField(null=True, blank=True, verbose_name="Progress")
	dificulties = models.TextField(null=True, blank=True, verbose_name="Dificulties")
	need_improv = models.TextField(null=True, blank=True, verbose_name="Need Improvement")
	enter_date = models.DateField(null=True, blank=True)
	eval_date = models.DateField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	usereval = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True, related_name="evalplanningauser")
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.eval} - {0.eval.employee}'
		return template.format(self)
	

class EvalPlanningB(models.Model):
	eval = models.ForeignKey(EvalPlanning, on_delete=models.CASCADE, null=True, blank=True, related_name="evalplanningb")
	parameter = models.ForeignKey(ParameterB, on_delete=models.CASCADE, null=True, blank=True, related_name="evalplanningb")
	progress = models.TextField(null=True, blank=True)
	dificulties = models.TextField(null=True, blank=True)
	need_improv = models.TextField(null=True, blank=True)
	datetime = models.DateTimeField(null=True, blank=True)
	enter_date = models.DateField(null=True, blank=True)
	eval_date = models.DateField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	usereval = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True, related_name="evalplanningbauser")
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.eval} - {0.eval.employee}'
		return template.format(self)
## END EVAL PLANNING
	

##EVAL
class Eval(models.Model):
	year = models.ForeignKey(EvalYear, on_delete=models.CASCADE, null=True, blank=True, related_name="eval")
	type = models.ForeignKey(EvalType, on_delete=models.CASCADE, null=True, blank=True, related_name="eval")
	employeeeval = models.ForeignKey(Employee, on_delete=models.CASCADE, null=True, blank=True, related_name="evalevaluator")
	positioneval = models.ForeignKey(Position, on_delete=models.CASCADE, null=True, blank=True, related_name="evalevaluator")
	uniteval = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name='evalevaluator')
	employee = models.ForeignKey(Employee, on_delete=models.CASCADE, null=True, blank=True, related_name="eval")
	category = models.ForeignKey(Category, on_delete=models.CASCADE, null=True, blank=True, related_name='eval')
	position = models.ForeignKey(Position, on_delete=models.CASCADE, null=True, blank=True, related_name='eval')
	department = models.ForeignKey(Department, on_delete=models.CASCADE, null=True, blank=True, related_name='eval')
	unit = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name='eval')
	start_date = models.DateField(null=True, blank=True)
	end_date = models.DateField(null=True, blank=True)
	emp_obj_date = models.DateField(null=True, blank=True)
	emp_beh_date = models.DateField(null=True, blank=True)
	empeval_obj_date = models.DateField(null=True, blank=True)
	empeval_beh_date = models.DateField(null=True, blank=True)
	score_a = models.IntegerField(null=True, blank=True)
	score_b = models.IntegerField(null=True, blank=True)
	total = models.IntegerField(null=True, blank=True)
	outstanding_perf = models.TextField(null=True, blank=True, verbose_name="Justification Of Outstanding Performance")
	unsatisfactory_perf_obj = models.TextField(null=True, blank=True, verbose_name="Justification Of Unsatisfactory Performance - Individual Objectives")
	unsatisfactory_perf_beh = models.TextField(null=True, blank=True, verbose_name="Justification Of Unsatisfactory Performance - Professional Behaviors")
	recognition_merit = models.TextField(null=True, blank=True, verbose_name="Recognition of Merit (Outstanding Performance)")
	just_non_evaluation = models.TextField(null=True, blank=True, verbose_name="Jusitification of Non-Evaluation")
	comment_next_evaluation = models.TextField(null=True, blank=True, verbose_name="Expectations, Conditions And / Or Requirements for Personal And Professional Development")
	is_lock = models.BooleanField(default=False, null=True)
	is_finish = models.BooleanField(default=False, null=True)
	datetime = models.DateTimeField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.employee} - {0.end_date}'
		return template.format(self)


class Evaluator(models.Model):
	eval = models.ForeignKey(Eval, on_delete=models.CASCADE, null=True, blank=True, related_name="evaluator")
	employee = models.ForeignKey(Employee, on_delete=models.CASCADE, null=True, blank=True, related_name="evaluator")
	position = models.ForeignKey(Position, on_delete=models.CASCADE, null=True, blank=True, related_name="evaluator")
	unit = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name='evaluator')
	def __str__(self):
		template = '{0.employee} - {0.position}'
		return template.format(self)

class EvalDate(models.Model):
	eval = models.ForeignKey(Eval, on_delete=models.CASCADE, null=True, blank=True, related_name="evaldate")
	date_a_1 = models.DateField(null=True, blank=True)
	date_a_2 = models.DateField(null=True, blank=True)
	date_b_1 = models.DateField(null=True, blank=True)
	date_b_2 = models.DateField(null=True, blank=True)
	def __str__(self):
		template = '{0.eval} - {0.date_a_1}'
		return template.format(self)

class EvalFinalScore(models.Model):
	eval = models.ForeignKey(Eval, on_delete=models.CASCADE, null=True, blank=True, related_name="evalfinalscore")
	a = models.IntegerField(null=True, blank=True)
	b = models.IntegerField(null=True, blank=True)
	c = models.IntegerField(null=True, blank=True)
	d = models.IntegerField(null=True, blank=True)
	e = models.IntegerField(null=True, blank=True)
	def __str__(self):
		template = '{0.eval}: {0.a}/{0.b}/{0.c}/{0.d}/{0.e}'
		return template.format(self)
#
class EvalDetA(models.Model):
	eval = models.ForeignKey(Eval, on_delete=models.CASCADE, null=True, blank=True, related_name="evaldeta")
	parameter = models.ForeignKey(EvalPlanningA, on_delete=models.CASCADE, null=True, blank=True, related_name="evaldeta")
	choice = models.ForeignKey(EvalChoice, on_delete=models.CASCADE, null=True, blank=True, related_name="evaldeta")
	comments = models.TextField(null=True, blank=True, verbose_name="Komentariu")
	datetime = models.DateTimeField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.parameter}: {0.choice}'
		return template.format(self)

class EvalDetB(models.Model):
	eval = models.ForeignKey(Eval, on_delete=models.CASCADE, null=True, blank=True, related_name="evaldetb")
	parameter = models.ForeignKey(EvalPlanningB, on_delete=models.CASCADE, null=True, blank=True, related_name="evaldetb")
	choice = models.ForeignKey(EvalChoice, on_delete=models.CASCADE, null=True, blank=True, related_name="evaldetb")
	comments = models.TextField(null=True, blank=True, verbose_name="Komentariu")
	datetime = models.DateTimeField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.parameter}: {0.choice}'
		return template.format(self)
	
# SELF ASSESSMENT
class EvalSelf(models.Model):
	year = models.ForeignKey(EvalYear, on_delete=models.CASCADE, null=True, blank=True, related_name="evalself")
	type = models.ForeignKey(EvalType, on_delete=models.CASCADE, null=True, blank=True, related_name="evalself")
	employee = models.ForeignKey(Employee, on_delete=models.CASCADE, null=True, blank=True, related_name="evalself")
	category = models.ForeignKey(Category, on_delete=models.CASCADE, null=True, blank=True, related_name='evalself')
	position = models.ForeignKey(Position, on_delete=models.CASCADE, null=True, blank=True, related_name='evalself')
	department = models.ForeignKey(Department, on_delete=models.CASCADE, null=True, blank=True, related_name='evalself')
	unit = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name='evalself')
	start_date = models.DateField(null=True, blank=True)
	end_date = models.DateField(null=True, blank=True)
	ind_date = models.DateField(null=True, blank=True)
	beh_date = models.DateField(null=True, blank=True)
	comments = models.TextField(null=True, blank=True)
	is_lock = models.BooleanField(default=False, null=True)
	is_finish = models.BooleanField(default=False, null=True)
	datetime = models.DateTimeField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.employee} - {0.end_date}'
		return template.format(self)

class EvalSelfDetA(models.Model):
	eval = models.ForeignKey(EvalSelf, on_delete=models.CASCADE, null=True, blank=True, related_name="evalselfdeta")
	parameter = models.ForeignKey(EvalPlanningA, on_delete=models.CASCADE, null=True, blank=True, related_name="evalselfdeta")
	comments_a = models.TextField(null=True, blank=True, verbose_name="Goal Exceeded")
	comments_b = models.TextField(null=True, blank=True, verbose_name="Goal Achieved")
	comments_c = models.TextField(null=True, blank=True, verbose_name="Goal Not Reached")
	datetime = models.DateTimeField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.parameter}'
		return template.format(self)

class EvalSelfDetB(models.Model):
	eval = models.ForeignKey(EvalSelf, on_delete=models.CASCADE, null=True, blank=True, related_name="evalselfdetb")
	parameter = models.ForeignKey(EvalPlanningB, on_delete=models.CASCADE, null=True, blank=True, related_name="evalselfdetb")
	comments_a = models.TextField(null=True, blank=True)
	comments_b = models.TextField(null=True, blank=True)
	comments_c = models.TextField(null=True, blank=True)
	datetime = models.DateTimeField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.parameter}'
		return template.format(self)




# EVAL PRE - ASSESS
class EvalPreAssessment(models.Model):
	year = models.ForeignKey(EvalYear, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreass")
	type = models.ForeignKey(EvalType, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreass")
	employeeeval = models.ForeignKey(Employee, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassempeval")
	positioneval = models.ForeignKey(Position, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassempeval")
	uniteval = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name='evalpreassempeval')
	employee = models.ForeignKey(Employee, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassemp")
	category = models.ForeignKey(Category, on_delete=models.CASCADE, null=True, blank=True, related_name='evalpreassemp')
	position = models.ForeignKey(Position, on_delete=models.CASCADE, null=True, blank=True, related_name='evalpreassemp')
	department = models.ForeignKey(Department, on_delete=models.CASCADE, null=True, blank=True, related_name='evalpreass')
	unit = models.ForeignKey(Unit, on_delete=models.CASCADE, null=True, blank=True, related_name='evalpreassemp')
	start_date = models.DateField(null=True, blank=True)
	end_date = models.DateField(null=True, blank=True)
	eval_ind_date = models.DateField(null=True, blank=True)
	eval_beh_date = models.DateField(null=True, blank=True)
	comments = models.TextField(null=True, blank=True)
	objective = models.TextField(null=True, blank=True, verbose_name="Objectives")
	is_lock = models.BooleanField(default=False, null=True)
	is_finish = models.BooleanField(default=False, null=True)
	datetime = models.DateTimeField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.employee} - {0.end_date}'
		return template.format(self)
	

class EvalPreAssessmentA(models.Model):
	PRE_ASS_CHOICE_A = [
        ('one', 'Goal Exceeded (Explain)'),
        ('two', 'Goal Achived (Explain)'),
        ('three', 'Goal not Reached (Explain)'),
    ]
	eval = models.ForeignKey(EvalPreAssessment, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassa")
	plan_objective = models.ForeignKey(EvalPlanningA, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassaobjective")
	scored = models.CharField(max_length=100, choices=PRE_ASS_CHOICE_A, null=True, blank=True)
	enter_date = models.DateField(null=True, blank=True)
	eval_date = models.DateField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	usereval = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassauser")
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.eval} - {0.eval.employee}'
		return template.format(self)
	

class EvalPreAssessmentB(models.Model):
	PRE_ASS_CHOICE_B = [
        ('one', 'Demonstrated Competence at a High Level'),
        ('two', 'Goal Achived'),
        ('three', 'Goal not Reached'),
    ]
	eval = models.ForeignKey(EvalPreAssessment, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassb")
	parameter = models.ForeignKey(EvalPlanningB, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassbobjective")
	scored = models.CharField(max_length=100, choices=PRE_ASS_CHOICE_B, null=True, blank=True)
	enter_date = models.DateField(null=True, blank=True)
	eval_date = models.DateField(null=True, blank=True)
	user = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True)
	usereval = models.ForeignKey(User, on_delete=models.CASCADE, null=True, blank=True, related_name="evalpreassbuser")
	hashed = models.CharField(max_length=32, null=True, blank=True)
	def __str__(self):
		template = '{0.eval} - {0.eval.employee}'
		return template.format(self)





import datetime
from django.shortcuts import render, redirect, get_object_or_404
from django.contrib.auth.decorators import login_required
from settings_app.decorators import allowed_users
from django.contrib import messages
from django.db.models import Sum
from employee.models import CurEmpDivision, Employee
from contract.models import Category, Contract, EmpPosition
from perform.models import ParameterA, ParameterB, Eval, EvalDetA, EvalDetB, EvalYear, \
EvalPlanning, EvalPlanningA, EvalPlanningB, EvalPreAssessment, EvalPreAssessmentA, EvalSelf, \
EvalSelfDetA, EvalSelfDetB, EvalFinalScore
from perform.forms import *
from settings_app.utils import getnewid
from settings_app.user_utils import c_unit, c_staff


@login_required
def StaffListPerfom(request):
    group = request.user.groups.all()[0].name
    cats = Category.objects.filter().all().order_by('id')
    employee = c_staff(request.user)
    eval_year = EvalYear.objects.filter(is_active=True).last()
    
    planning = EvalPlanning.objects.filter(employee=employee, year=eval_year).last()
    preass = EvalPreAssessment.objects.filter(employee=employee, year=eval_year).last()
    selfeval = EvalSelf.objects.filter(employee=employee, year=eval_year).last()
    eval = Eval.objects.filter(employee=employee, year=eval_year).last()
    check_plan = EvalPlanningA.objects.filter(eval=planning).exists()
    context = {
        'group': group, 
        'planning': planning,  'preass': preass, 'selfeval': selfeval, 'eval':eval,        
        'employee':employee, 'check_plan':check_plan, 'ayear':eval_year.year,
        'title': 'Lista Avaliasaun', 'legend': f'Lista Avaliasaun iha Tinan {eval_year.year}'
    }
    return render(request, 'perform_staff/list.html', context)

@login_required
def StaffPerfomPlanDetail(request, hashid):
    objects = get_object_or_404(EvalPlanning,hashed=hashid)
    user = c_staff(request.user)
    check_emp = True if user == objects.employee else False
    individual = EvalPlanningA.objects.filter(eval=objects)
    behavior = EvalPlanningB.objects.filter(eval=objects)
    context = {
        'title': 'Detail Planning and Monitoring', 'legend': 'Planning and Monitoring Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior
    }
    return render(request,'perform_staff/plan_detail.html', context)

@login_required
def StaffPerfomPreAssDetail(request, hashid):
    objects = get_object_or_404(EvalPreAssessment,hashed=hashid)
    user = c_staff(request.user)
    check_emp = True if user == objects.employee else False
    individual = EvalPreAssessmentA.objects.filter(eval=objects)
    behavior = EvalPreAssessmentB.objects.filter(eval=objects)
    context = {
        'title': 'Detail Pre-Assessment', 'legend': 'Pre-Assessment Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior
    }
    return render(request,'perform_staff/preass_detail.html', context)

@login_required
def StaffPerformSelfDetail(request, hashid):
    objects = get_object_or_404(EvalSelf,hashed=hashid)
    user = c_staff(request.user)
    check_emp = True if user == objects.employee else False
    individual = EvalSelfDetA.objects.filter(eval=objects)
    behavior = EvalSelfDetB.objects.filter(eval=objects)
    context = {
        'title': 'Detail Self Evaluation', 'legend': 'Self Evaluation Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior
    }
    return render(request,'perform_staff/self_detail.html', context)

@login_required
def StaffEvalDetail(request, hashid, hashid2):
    objects = get_object_or_404(Eval,hashed=hashid)
    user = c_staff(request.user)
    plan = get_object_or_404(EvalPlanning,hashed=hashid2)
    check_emp = True if user == objects.employee else False
    individual = EvalDetA.objects.filter(eval=objects)
    behavior = EvalDetB.objects.filter(eval=objects)
    finalscore = EvalFinalScore.objects.filter(eval=objects).last()
    context = {
        'title': 'Detail Evaluation', 'legend': 'Evaluation Sheet', \
        'objects': objects, 'check_emp':check_emp, 'individual':individual, 'behavior':behavior, \
		'plan':plan, 'finalscore':finalscore
    }
    return render(request,'perform_staff/eval_detail.html', context)




def f_finalscore(score):
	a,b,c = "","",""
	if score > 449:
		a = "DIAK LOS"
		b = "A"
		c = "PROLONGO KONTRATU"
	elif score > 349:
		a = "DIAK"
		b = "B"
		c = "PROLONGO KONTRATU"
	elif score > 299:
		a = "SUFICIENTE"
		b = "C"
		c = "CHAMA DE ATENSAUN"
	else:
		a = "LADIAK"
		b = "D"
		c = "HAPARA KONTRATU"
	return a,b,c


# Generated by Django 3.2 on 2023-02-18 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0015_rename_eval_obj_date_evalpreassessment_eval_beh_date'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evalself',
            old_name='eval_date',
            new_name='eval_beh_date',
        ),
        migrations.AddField(
            model_name='evalself',
            name='eval_ind_date',
            field=models.DateField(blank=True, null=True),
        ),
    ]



# Generated by Django 3.2 on 2023-03-07 01:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('perform', '0020_auto_20230307_1026'),
    ]

    operations = [
        migrations.AddField(
            model_name='eval',
            name='comment_next_evaluation',
            field=models.TextField(blank=True, null=True, verbose_name='Expectations, Conditions And / Or Requirements for Personal And Professional Development'),
        ),
        migrations.AddField(
            model_name='eval',
            name='just_non_evaluation',
            field=models.TextField(blank=True, null=True, verbose_name='Jusitification of Non-Evaluation'),
        ),
        migrations.AddField(
            model_name='eval',
            name='outstanding_perf',
            field=models.TextField(blank=True, null=True, verbose_name='Justification Of Outstanding Performance'),
        ),
        migrations.AddField(
            model_name='eval',
            name='recognition_merit',
            field=models.TextField(blank=True, null=True, verbose_name='Recognition of Merit (Outstanding Performance)'),
        ),
        migrations.AddField(
            model_name='eval',
            name='unsatisfactory_perf_beh',
            field=models.TextField(blank=True, null=True, verbose_name='Justification Of Unsatisfactory Performance - Professional Behaviors'),
        ),
        migrations.AddField(
            model_name='eval',
            name='unsatisfactory_perf_obj',
            field=models.TextField(blank=True, null=True, verbose_name='Justification Of Unsatisfactory Performance - Individual Objectives'),
        ),
    ]
